package com.servicemall.website.micro;

import java.util.List;
import java.util.Map;
import java.util.HashMap;

import javax.servlet.http.HttpServletRequest;

import com.servicemall.website.service.SliderService;
import io.swagger.annotations.Api;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import team.bangbang.common.data.Pagination;
import team.bangbang.common.data.response.ResponseBase;
import team.bangbang.common.data.response.DataResponse;
import team.bangbang.common.log.OperationLog;
import team.bangbang.spring.parameter.EntityParam;

import com.servicemall.website.data.Slider;

/**
 * 轮播图 - 微服务
 *
 * 对应Feign：com.servicemall.website.feign.SliderFeign
 *
 * @author 帮帮组
 * @version 1.0  2020-12-08
 */
@Api(description = "ServiceMall首页轮播图接口")
@RestController
@CrossOrigin(allowCredentials="true", allowedHeaders="*", origins="*", maxAge=3600)
@RequestMapping("/microservice/website/slider")
public final class SliderMicro {
	/**************************************************************************
	 * ！！除非设计、指导人员有特别说明，否则此处不得随意增加、修改、删除！！
	 * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
	 *
	 *************************************************************************/

	private static final Logger logger= LoggerFactory.getLogger(SliderMicro.class);

	/**
	 * 插入一条轮播图
	 * @param slider 插入数据，不能为空
	 * @param request http请求
	 * @return 1：成功，2 失败
	 */
	@PostMapping("/insert")
	public ResponseBase insert(@RequestBody Slider slider,HttpServletRequest request){
		//是否存在重复轮播图
		if(exist(slider)){
			return ResponseBase.DATA_DUPLICATE;
		}
		int n= SliderService.insert(slider);
		if(n!=1){
			return ResponseBase.ERROR_LOGIC;
		}
		// 日志记录
		OperationLog log=new OperationLog();
		log.setType("新增轮播图");
		log.setBizData(slider);
		request.setAttribute("log",log);

		DataResponse<Slider> result=new DataResponse<Slider>();
		result.setData(slider);
		return result;
	}

	@PostMapping("/delete")
	public ResponseBase delete(@RequestBody Slider slider,HttpServletRequest request){
		if (slider.getId()==null||slider.getId()==0l){
			return ResponseBase.DATA_PROTECTED;
		}
		//获取待删除的对象，用于日志记录
		slider=SliderService.getObject(slider, (String) null);
		if (slider==null){
			return ResponseBase.DATA_NOT_FOUND;
		}
		//限定条件
		Slider where =new Slider();
		where.setId(slider.getId());

		int result=SliderService.delete(where,null);

		if (result!=1){
			return ResponseBase.DATA_NOT_FOUND;
		}
		// 记录日志
		OperationLog log = new OperationLog();
		log.setType("删除轮播图");
		log.setBizData(where);
		request.setAttribute("log",log);
		return ResponseBase.SUCCESS;

	}

	@PostMapping("/update")
	public ResponseBase update(@RequestBody Slider slider,HttpServletRequest request){
		//根据新数据id更新
		Long id=slider.getId();
		if (id==null|| id==0l){
			return ResponseBase.DATA_NOT_FOUND;
		}
		//是否存在重复记录？
		if(exist(slider)){
			return ResponseBase.DATA_DUPLICATE;
		}

		//第一个参数slider 取关键字slider.id为条件
		//第三个参数slider，取Slider内关键字段之外属性数据
		int n=SliderService.update(slider,null,slider);

		if(n!=1){
			return ResponseBase.DATA_NOT_FOUND;
		}
		//记录日志
		OperationLog log=new OperationLog();
		log.setType("修改轮播图");
		log.setBizData(slider);
		request.setAttribute("log",log);

		// 重新查询，返回到前端
		slider=SliderService.getObject(slider, (String) null);
		DataResponse<Slider> result=new DataResponse<Slider>();
		result.setData(slider);
		return result;
	}

	@PostMapping("/get")
	public ResponseBase get(@RequestBody Slider slider){
		if(slider.getId()==null||slider.getId()==0l){
			return ResponseBase.DATA_NOT_FOUND;
		}
		//查询
		SliderService.getObject(slider, (String) null);
		DataResponse<Slider> result=new DataResponse<Slider>();
		result.setData(slider);
		return result;
	}


	/**
	 * 获取符合条件的轮播图数据
	 * @param slider 查询条件不能为null
	 * @return 返回记录数量
	 */
	@PostMapping("/count")
	public ResponseBase count(@RequestBody Slider slider){
		// 附加限定条件，这里可以修改附加限定条件
		String appendix=null;
		int n=SliderService.count(slider,appendix);
		DataResponse<Integer> result=new DataResponse<Integer>();

		result.setData(n);
		return result;
	}




	/**
	 * 查询多条轮播图，并转化为相应的POJO对象列表
	 *
	 *
	 * @return 返回结果记录，并转化为相应的POJO对象列表
	 */
	@PostMapping("/slidelist")
	@ResponseBody
	public ResponseBase slidelist() {


		DataResponse<Map<String, Object>> result = new DataResponse<Map<String, Object>>();
		Map<String, Object> datas = new HashMap<String, Object>();
		datas.put("list", "sliderList");
		Slider slider = new Slider();
		result.setData(datas);

		return result;
	}

	/**
	 * 用于在新增，修改时刻检查数据库中是否存在重复记录
	 * @param slider  将要修改的轮播图
	 * @return    true 已经存在，false，不存在
	 */
	private boolean exist(Slider slider) {
		//检查修改的轮播图是否有重复记录
		Slider form=new Slider();
		// 关键字限定条件
		String str = (slider.getId()==null? null:"id!="+slider.getId());

		// 其他限定条件



		return true;




	}
}
