package com.servicemall.website.service;

import com.servicemall.website.data.Slider;
import com.servicemall.website.mapper.SliderMapper;
import org.springframework.stereotype.Service;
import team.bangbang.common.CommonMPI;
import team.bangbang.common.data.Pagination;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;
/**
 * 轮播图 - Service
 *
 * @author chuli
 * @version 1.0  2020-12-08
 */

@Service
public final class SliderService {
    /*轮播图（Slider）Mapper*/
    @Resource
    private SliderMapper _sliderMapper = null;

    private static SliderMapper sliderMapper = null;

    @PostConstruct
    public void init() {
        sliderMapper = _sliderMapper;
    }

    /**
     * 获取轮播图信息
     *
     * @param slider
     * @param id
     * @return
     */
    public static Slider getObject(Slider slider, Long id) {
        if (sliderMapper == null) {
            return null;
        }
        //参数校验
        if(id == null || id == 0l) {
            return null;
        }
        // 查询条件
        slider =new Slider();
        slider.setId(id);
        return getObject(slider, (Long) null);
    }

    /**
     * 查询一条轮播图
     * @param slider 查询条件不能为空
     * @param appendix
     * @return
     */
    public static Slider getObject(Slider slider,String appendix){
        if(sliderMapper==null){
            return null;
        }
        //参数校验
        if(slider==null&&(appendix==null)||appendix.trim().length()==0){
            return null;
        }
        return sliderMapper.getObject(slider,appendix);
    }

    public static int insert(Slider data){
        if(sliderMapper==null){
            return 0;
        }
        if (data.getId()==null){
            // 返回创建的关键字的值，如果系统自动生成，则此处不返回
            long id= CommonMPI.generateSequenceId();
            data.setId(id);
        }
        return sliderMapper.insert(data);
    }

    /**
     * 删除轮播图
     * @param where 删除条件，不能为null
     * @param appendix 附加限定条件
     * @return
     */

    public static int delete(Slider where,String appendix){
        if (sliderMapper==null){
            return 0;
        }
        return sliderMapper.delete(where,appendix);
    }

    /**
     * 修改轮播图
     * @param where 更新条件，不能为null
     * @param appendix  附近限定条件
     * @param data       更新数据，不能为null
     * @return
     */

    public static int update(Slider where,String appendix,Slider data){
        if(sliderMapper==null){
            return 0;
        }
        return sliderMapper.update(where,appendix,data);
    }

    /**
     * 查询多条轮播图，并转化为相应的POJO对象列表
     * @param where
     * @param appendix
     * @param pagination
     * @return
     */
    public static List<Slider> list(Slider where, String appendix, Pagination pagination){
        if(sliderMapper==null ){
            return Collections.emptyList();
        }
        return sliderMapper.list(where,appendix,pagination);
    }

    /**
     * 获取符合条件的轮播图数据
     * @param where 查询条件，不能为空
     * @param appendix 附近条件
     * @return
     */
    public static int count(Slider where,String appendix){
        if(sliderMapper==null){
            return 0;
        }
        return sliderMapper.count(where,appendix);
    }

}
